from django import forms

from .models import SimpleBlogEntriesPlugin


class SimpleBlogEntriesPluginForm(forms.ModelForm):

    class Meta:
        model = SimpleBlogEntriesPlugin
        exclude = ('page', 'position', 'placeholder', 'language', 'plugin_type')



from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from django.conf import settings
from django.utils import translation
from django.utils.translation import ugettext_lazy as _
from djcms_blog.models import Blog

from .forms import SimpleBlogEntriesPluginForm
from .models import SimpleBlogEntriesPlugin


class SimpleBlogEntriesPluginCMS(CMSPluginBase):
    model = SimpleBlogEntriesPlugin
    module = _("Django CMS Blog")
    name = _('Simple Blog Entries Plugin')
    render_template = "djcms_blog_plugin/simple_blog_entries.html"
    allow_children = False
    form = SimpleBlogEntriesPluginForm
    language = None

    def render(self, context, instance, placeholder):
        self.language = translation.get_language()
        context = super(SimpleBlogEntriesPluginCMS, self).render(context, instance, placeholder)
        blog = Blog.objects.get(pk=settings.DJCMS_BLOG_ID)
        blog_lang_object = blog.get_language_object(self.language)
        instance.get_posts = list(blog.get_posts())[:settings.DJCMS_BLOG_ENTRIES_NUMBER]
        instance.title = instance.custom_blog_title or blog_lang_object.title
        for post in instance.get_posts:
            post_object = post.language_object(self.language)
            post.title = post_object.title
            post.description = post_object.description
            post.published_date = post_object.published_date
        return context


plugin_pool.register_plugin(SimpleBlogEntriesPluginCMS)



# -*- coding: utf-8 -*-
from cms.api import add_plugin
from cms.models import Placeholder
from cms.plugin_rendering import ContentRenderer
from django.contrib.auth.models import User
from django.test import TestCase
from django.test.client import RequestFactory
from djcms_blog.models import Blog, BlogTitle, Post, PostTitle, Tag, Author

from djcms_blog_plugin.cms_plugins import SimpleBlogEntriesPluginCMS


class SimpleBlogEntriesPluginTestCase(TestCase):

    def setUp(self):
        self.factory = RequestFactory()
        self.user = User.objects.create_user("carlosmart", "me@carlosmart.co", "123123")
        self.user.first_name = "Carlos"
        self.user.last_name = "Martinez"
        self.author = Author.objects.create(
            user=self.user,
            cover="author-cover.jpg",
            image="author-image.jpg",
            slug="carlosmart",
            location="Colombia",
            website="https://carlosmart.co",
            facebook_profile="https://facebook.com/carlosmart626",
            twitter_profile="https://twitter.com/carlosmart626",
            block_header="",
            block_footer=""
        )
        self.blog = Blog.objects.create(
            title="My Blog",
            slug="my-blog",
            cover="cover.jpg",
            block_header="",
            block_footer=""
        )
        self.blog_title = BlogTitle.objects.create(
            blog=self.blog,
            language="en",
            title="My blog",
            description="My blog description",
        )
        self.tag = Tag.objects.create(
            blog=self.blog,
            cover="tag_cover.jpg",
            name="My Tag",
            slug="my-tag",
            color="blue",
        )
        self.post_1 = Post.objects.create(
            blog=self.blog,
            title="My post",
            slug="my-post",
            author=self.author,
        )
        self.post_1_title = PostTitle.objects.create(
            post=self.post_1,
            title="My post",
            language="en",
            description="My post description",
            body="My post body",
            publisher_is_draft=False,
            published=True
        )
        self.post_2 = Post.objects.create(
            blog=self.blog,
            title="My post 2",
            slug="my-post 2",
            author=self.author,
        )
        self.post_2_title = PostTitle.objects.create(
            post=self.post_2,
            title="My post 2",
            language="en",
            description="My post 2 description",
            body="My post 2 body",
            publisher_is_draft=False,
            published=True
        )

    def test_models(self):
        simple_blog_plugin_simple_cms = SimpleBlogEntriesPluginCMS()
        self.assertIsNotNone(simple_blog_plugin_simple_cms)
        placeholder = Placeholder.objects.create(slot='test')
        model_instance = add_plugin(
            placeholder,
            SimpleBlogEntriesPluginCMS,
            'en',
        )
        renderer = ContentRenderer(request=RequestFactory())
        html = renderer.render_plugin(model_instance, {})
        self.assertIn("My post", html)
        self.assertIn("My post description", html)
        self.assertIn("My post 2", html)
        self.assertIn("My post 2 description", html)
        self.assertIn("carlosmart", html)
        self.assertIn("My blog", html)

        model_instance = add_plugin(
            placeholder,
            SimpleBlogEntriesPluginCMS,
            'en',
        )
        model_instance.custom_blog_title = "This is my new blog"
        model_instance.save()
        renderer = ContentRenderer(request=RequestFactory())
        html = renderer.render_plugin(model_instance, {})
        self.assertIn("My post", html)
        self.assertIn("My post description", html)
        self.assertIn("My post 2", html)
        self.assertIn("My post 2 description", html)
        self.assertIn("carlosmart", html)
        self.assertIn("This is my new blog", html)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import os
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

SECRET_KEY = '1'
INSTALLED_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.sites',
    'django.contrib.admin',
    'django.contrib.humanize',
    'cms',
    'menus',
    'treebeard',

    'djcms_blog',

    'djcms_blog_plugin',
)
TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': ['', ],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]
CMS_LANGUAGES = {
    1: [{
        'code': 'en',
        'name': 'English',
    }]
}
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME': os.path.join(BASE_DIR, 'db.sqlite3')
    }
}
LANGUAGE_CODE = 'en'

DJCMS_BLOG_ID = 1
DJCMS_BLOG_ENTRIES_NUMBER = 5
SITE_ID = 1



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages
from djcms_blog_plugin import __version__

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    'django-cms>=3.2.0',
    'djcms_blog>=v0.1.8', 'django'
]

setup_requirements = ['pytest-runner', ]

test_requirements = ['pytest', ]

setup(
    author="Carlos Martinez",
    author_email='me@carlosmart.co',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="DjangoCMS Blog plugin",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='djcms_blog_plugin',
    name='djcms_blog_plugin',
    packages=find_packages(include=['djcms_blog_plugin']),
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/carlosmart626/djcms_blog_plugin',
    version=__version__,
    zip_safe=False,
)



from cms.models import CMSPlugin
from django.db import models
from django.utils.encoding import python_2_unicode_compatible
from django.utils.translation import ugettext_lazy as _


@python_2_unicode_compatible
class SimpleBlogEntriesPlugin(CMSPlugin):
    """
    Segment
    """
    label = models.CharField(
        verbose_name=_('Label'),
        blank=True,
        max_length=255,
        help_text=_('Overrides the display name in the structure mode.'),
    )
    custom_blog_title = models.CharField(
        verbose_name=_('Custom Title'),
        blank=True,
        max_length=255,
        help_text=_('Overrides the display name in the widget.'),
    )
    # Add an app namespace to related_name to avoid field name clashes
    # with any other plugins that have a field with the same name as the
    # lowercase of the class name of this model.
    # https://github.com/divio/django-cms/issues/5030
    cmsplugin_ptr = models.OneToOneField(
        CMSPlugin,
        related_name='%(app_label)s_%(class)s',
        parent_link=True,
        on_delete=models.CASCADE
    )

    def __str__(self):
        return self.label

    def get_short_description(self):
        return "{}, Simple Blog Plugin".format(self.label)



# -*- coding: utf-8 -*-
from django.test import TestCase

from djcms_blog_plugin.models import SimpleBlogEntriesPlugin


class SimpleBlogEntriesPluginTestCase(TestCase):

    def setUp(self):
        pass

    def test_models(self):
        simple_blog_plugin = SimpleBlogEntriesPlugin.objects.create(
            label='Test',
            custom_blog_title='My Blog',
        )
        self.assertEqual("Test", str(simple_blog_plugin))
        self.assertEqual("Test, Simple Blog Plugin", simple_blog_plugin.get_short_description())
